@@ -3,7 +3,7 @@ package Crypt::JWT;
 use strict;
 use warnings;
 
-our $VERSION = '0.027';
+our $VERSION = '0.028';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(decode_jwt encode_jwt)] );
@@ -12,7 +12,7 @@ our @EXPORT = qw();
 
 use Carp;
 use Crypt::Misc qw(decode_b64u encode_b64u);
-use JSON::MaybeXS qw(decode_json encode_json);
+use JSON qw(decode_json encode_json);
 use Crypt::PK::RSA;
 use Crypt::PK::ECC;
 use Crypt::PK::Ed25519;
